*******************************************************************************
/* 
PROJECT: BIS DATA                                            

OUTPUT OF THIS DO FILE:                                                   
- uses data from anx6a.csv and anx6b.csv to build a panel summary
	
WRITTEN BY: Gregorio Impavido (gimpavido@imf.org)

WRITTEN WHEN:   10 May, 2012
*/
*******************************************************************************

*******************************************************************************
****************************** DEFINE ENVIRONMENT *****************************
*******************************************************************************
version 12.0
clear all
capture log close
set logtype text
set more off

* on Q drive
* local base "//data2/EUR/DATA/UNIT/EE/Data/panelchart"

* on C drive
local base "//data4/users2/GIMPAVIDO/My Documents/Stata/Data/panelchart"
local dta "`base'/dta"
local wkdir "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"
local out  "//data4/users2/GIMPAVIDO/My Documents/FY13/2012.09.01 - future banking CESEE WP/figures"

/*
global q_start 2000q1
global q_end 2012q2
*/

*******************************************************************************
************************************ START ************************************
*******************************************************************************
cd "`wkdir'"

* load base data
local where `: di subinstr(`"`base'"', "panelchart", "BIS/t6",1)'
use "`where'/dta/anx6.dta", clear

drop anx6a_estass- anx6c_usdlia_fx
drop if name20char=="Turkey" | name20char=="Russian Federation"

* merge GDPs
rename time timeq // this is the name for Q obs in the using dbase
merge 1:1 idifs timeq using "`base'/gdp/dta/macro-all.dta", keepusing(ngdpd ngdp_r pppgdp)

* change into million
foreach var of varlist ngdpd ngdp_r pppgdp {
	local varlab `: variable label `var''
	local varlab1 `: di subinstr("`varlab'","type -notes-","Million",.)'
	label var `var' "`varlab1'"
	replace `var' = `var'*1000
	notes drop `var' in 3
}

* gen dummies
gen lac   = 	(reg=="Latin America/Caribbean":reg & ngdpd>20000)
gen asia  = 	(reg=="Asia & Pacific":reg & ngdpd>20000 & name20char!="Taiwan")
* outsheet name20char ep* using "`out'/wp-f08.txt" if ep_cesee<. | ep_lac<. | ep_asia<. , replace

rename timeq time

* interpolate GDPs
foreach var of varlist ngdpd ngdp_r pppgdp {
ipolate `var' time, by(name20bis) gen(`var'_ipol) epolate
	local varlab `: variable label `var''
	local varlab1 `: di subinstr("`varlab'","Million","Million linear interp.",.)'
	label var `var'_ipol "`varlab1'"
	drop `var'
	}

* keep if inrange(time,q(2000q1),q(2013q4))

* gen rates of changes
bysort id (time) : gen double ngdp_r_g = 100*(ngdp_r/L4.ngdp_r-1)

* gen weights
keep if !missing(ngdp_r_ipol) & !missing(pppgdp_ipol)
bysort id (time) : gen double ngdp_r_ipol_g = 100*(ngdp_r_ipol/L4.ngdp_r_ipol-1)

bysort time : egen sum_cesee = total(pppgdp_ipol) if cesee==1
bysort time : egen sum_lac = total(pppgdp_ipol) if lac==1
bysort time : egen sum_asia = total(pppgdp_ipol) if asia==1

gen w_cesee = pppgdp_ipol/sum_cesee
gen w_lac = pppgdp_ipol/sum_lac
gen w_asia = pppgdp_ipol/sum_asia

* gen weighted rates of changes
gen double ngdp_r_g_w_cesee = ngdp_r_g*w_cesee
gen double ngdp_r_g_w_lac = ngdp_r_g*w_lac
gen double ngdp_r_g_w_asia = ngdp_r_g*w_asia

bysort time : egen cesee_g = total(ngdp_r_g_w_cesee)
bysort time : egen lac_g = total(ngdp_r_g_w_lac)
bysort time : egen asia_g = total(ngdp_r_g_w_asia)

gen wg = cesee_g
replace wg = lac_g if lac==1
replace wg = asia_g if asia==1

gen dum = cesee
replace dum = lac*2 if lac==1
replace dum = asia*3 if asia==1

keep idifs- reg dum wg
drop if dum==0

collapse wg, by(dum time)

outsheet time wg dum using "`out'/wp-f04.txt" , replace
graph twoway 																			///
(line wg time if dum==1 & inrange(time,q(2001q1),q(2012q3))) 							///
(line wg time if dum==2 & inrange(time,q(2001q1),q(2012q3))) 							///
(line wg time if dum==3 & inrange(time,q(2001q1),q(2012q3))), 							///
yline(0)																				///
title("Figure 4. Evolution of Real GDP Growth in Emerging Markets 1/", span ring(7) position(11) size(*0.8)) ///
subtitle("({it:YoY, percent})", span ring(6) position(11) size(small)) 					///
ytitle(" ") 																			///
ylabel(, ang(h) gstyle(major) glcolor(gs12))											///
xtitle(" ") 																			///
tlabel(, format(%tqCCYY))																///
legend(order(1 2 3) label(1 "CESEE") label(2 "LAC") 										///
	label(3 "Asia") 																	///
	cols() rows(1) size(vsmall) symxsize(vsmall) symysize(vsmall) 						///
	ring(6) position(1) region(fcolor(ltbluishgray) lstyle(none)) bmargin(zero)) 		///
note("Notes: 1/ Annual real GDP is interpolated with time varying PPP GDP weights. Countries in the aggregates are listed in Figure 2."	///
"Sources: IMF WEO and authors' calculations.", size(vsmall) span)						///
graphregion(fcolor(ltbluishgray)) ysize() xsize() plotregion(style(none)) 
graph export "`out'/wp-f04.png", width(2500) replace








